@@ -4,14 +4,14 @@ import sys
 def read_all():
     fails = 0
     for line in sys.stdin:
-        if 'FAIL' in line:
+        if "FAIL" in line:
             fails += 1
-    print("%d lines with 'FAIL' found!" % fails)
+    print(f"{fails} lines with 'FAIL' found!")
 
 
 def read_some():
     for line in sys.stdin:
-        if 'FAIL' in line:
+        if "FAIL" in line:
             print("Line with 'FAIL' found!")
             sys.stdin.close()
             break
