@@ -1,7 +1,12 @@
 class DupeHybridKeywords:
-    names = ['defined twice', 'DEFINED TWICE',
-             'Embedded ${twice}', 'EMBEDDED ${ARG}',
-             'Exact dupe is ok', 'Exact dupe is ok']
+    names = [
+        "defined twice",
+        "DEFINED TWICE",
+        "Embedded ${twice}",
+        "EMBEDDED ${ARG}",
+        "Exact dupe is ok",
+        "Exact dupe is ok",
+    ]
 
     def get_keyword_names(self):
         return self.names
