@@ -1,5 +1,4 @@
 from robot.libraries.BuiltIn import BuiltIn
-from robot.utils import is_string
 
 
 def get_result_or_error(*args):
@@ -11,11 +10,11 @@ def get_result_or_error(*args):
 
 def pretty(*args, **kwargs):
     args = [to_str(a) for a in args]
-    kwargs = ['%s:%s' % (k, to_str(v)) for k, v in sorted(kwargs.items())]
-    return ', '.join(args + kwargs)
+    kwargs = [f"{k}:{to_str(v)}" for k, v in sorted(kwargs.items())]
+    return ", ".join(args + kwargs)
 
 
 def to_str(arg):
-    if is_string(arg):
+    if isinstance(arg, str):
         return arg
-    return '%s (%s)' % (arg, type(arg).__name__)
+    return f"{arg} ({type(arg).__name__})"
