@@ -1,12 +1,12 @@
 from functools import wraps
 
-
-__all__ = ['keyword_using_decorator', 'keyword_using_decorator_with_wraps']
+__all__ = ["keyword_using_decorator", "keyword_using_decorator_with_wraps"]
 
 
 def decorator(func):
     def wrapper(*args, **kwargs):
         return func(*args, **kwargs)
+
     return wrapper
 
 
@@ -14,12 +14,13 @@ def decorator_with_wraps(func):
     @wraps(func)
     def wrapper(*args, **kwargs):
         return func(*args, **kwargs)
+
     return wrapper
 
 
 @decorator
 def keyword_using_decorator(args, are_not, preserved=True):
-    return '%s %s %s' % (args, are_not, preserved)
+    return f"{args} {are_not} {preserved}"
 
 
 @decorator_with_wraps
