@@ -1,4 +1,4 @@
 class DocSetInInit:
 
     def __init__(self):
-        self.__doc__ = 'Doc set in __init__!!'
+        self.__doc__ = "Doc set in __init__!!"
