@@ -1,16 +1,16 @@
 try:
-    from collections.abc import Sequence, Mapping
+    from collections.abc import Mapping, Sequence
 except ImportError:
-    from collections import Sequence, Mapping
+    from collections import Mapping, Sequence
 
 
-__all__ = ['BROKEN_ITERABLE', 'BROKEN_SEQUENCE', 'BROKEN_MAPPING']
+__all__ = ["BROKEN_ITERABLE", "BROKEN_SEQUENCE", "BROKEN_MAPPING"]
 
 
 class BrokenIterable:
 
     def __iter__(self):
-        yield 'x'
+        yield "x"
         raise ValueError(type(self).__name__)
 
     def __getitem__(self, item):
@@ -28,7 +28,6 @@ class BrokenMapping(BrokenIterable, Mapping):
     pass
 
 
-
 BROKEN_ITERABLE = BrokenIterable()
 BROKEN_SEQUENCE = BrokenSequence()
 BROKEN_MAPPING = BrokenMapping()
