@@ -4,7 +4,7 @@ from robot.api.deco import not_keyword
 class HybridWithNotKeywordDecorator:
 
     def get_keyword_names(self):
-        return ['exposed_in_hybrid', 'not_exposed_in_hybrid']
+        return ["exposed_in_hybrid", "not_exposed_in_hybrid"]
 
     def exposed_in_hybrid(self):
         pass
