@@ -1,24 +1,23 @@
-from robot.libraries.BuiltIn import BuiltIn
 from robot.api import logger
+from robot.libraries.BuiltIn import BuiltIn
 
 
 class Importing:
 
     def __init__(self):
-        BuiltIn().import_library('String')
+        BuiltIn().import_library("String")
 
     def kw_from_lib_with_importing_init(self):
-        print('Keyword from library with importing __init__.')
+        print("Keyword from library with importing __init__.")
 
 
 class Initting:
 
     def __init__(self):
-        # This initializes the accesses library.
-        self.lib = BuiltIn().get_library_instance('InitImportingAndIniting.Initted')
+        self.lib = BuiltIn().get_library_instance("InitImportingAndIniting.Initted")
 
     def kw_from_lib_with_initting_init(self):
-        logger.info('Keyword from library with initting __init__.')
+        logger.info("Keyword from library with initting __init__.")
         self.lib.kw_from_lib_initted_by_init()
 
 
@@ -28,4 +27,4 @@ class Initted:
         self.id = id
 
     def kw_from_lib_initted_by_init(self):
-        print('Keyword from library initted by __init__ (id: %s).' % self.id)
+        print(f"Keyword from library initted by __init__ (id: {self.id}).")
