@@ -9,7 +9,7 @@ class LogLevels:
         self.messages = []
 
     def _log_message(self, msg):
-        self.messages.append('%s: %s' % (msg['level'], msg['message']))
+        self.messages.append(f"{msg['level']}: {msg['message']}")
 
     def logged_messages_should_be(self, *expected):
-        BuiltIn().should_be_equal('\n'.join(self.messages), '\n'.join(expected))
+        BuiltIn().should_be_equal("\n".join(self.messages), "\n".join(expected))
