@@ -1,10 +1,10 @@
-from robot.api.deco import library
-
 import sys
 
+from robot.api.deco import library
+
 
 class listener:
-    ROBOT_LISTENER_API_VERSION = 2
+    ROBOT_LISTENER_API_VERSION = "2"
 
     def start_test(self, name, attrs):
         self._stderr("START TEST")
@@ -13,15 +13,15 @@ class listener:
         self._stderr("END TEST")
 
     def log_message(self, msg):
-        self._stderr("MESSAGE %s" % msg['message'])
+        self._stderr(f"MESSAGE {msg['message']}")
 
     def close(self):
         self._stderr("CLOSE")
 
     def _stderr(self, msg):
-        sys.__stderr__.write("%s\n" % msg)
+        sys.__stderr__.write(f"{msg}\n")
 
 
-@library(scope='TEST CASE', listener=listener())
+@library(scope="TEST", listener=listener())
 class empty_listenerlibrary:
     pass
