@@ -1,4 +1,4 @@
 class MyLibFile2:
 
     def keyword_in_my_lib_file_2(self, arg):
-        return 'Hello %s!' % arg
+        return f"Hello {arg}!"
