@@ -7,4 +7,4 @@ class DynamicLibraryWithKwargsSupportWithoutArgspec(DynamicLibraryWithoutArgspec
         return getattr(self, name)(*args, **kwargs)
 
     def do_something_with_kwargs(self, a, b=2, c=3, **kwargs):
-        print(a, b, c, ' '.join('%s:%s' % (k, v) for k, v in kwargs.items()))
+        print(a, b, c, " ".join(f"{k}:{kwargs[k]}" for k in kwargs))
