@@ -9,12 +9,12 @@ class ContinuableApocalypseException(RuntimeError):
     ROBOT_CONTINUE_ON_FAILURE = True
 
 
-def exit_on_failure(msg='BANG!', standard=False, **config):
+def exit_on_failure(msg="BANG!", standard=False, **config):
     exception = FatalError if standard else FatalCatastrophyException
     raise exception(msg, **config)
 
 
-def raise_continuable_failure(msg='Can be continued', standard=False):
+def raise_continuable_failure(msg="Can be continued", standard=False):
     exception = ContinuableFailure if standard else ContinuableApocalypseException
     raise exception(msg)
 
