@@ -3,15 +3,15 @@ class NewStyleClassLibrary:
     def mirror(self, arg):
         arg = list(arg)
         arg.reverse()
-        return ''.join(arg)
+        return "".join(arg)
 
     @property
     def property_getter(self):
-        raise SystemExit('This should not be called, ever!!!')
+        raise SystemExit("This should not be called, ever!!!")
 
     @property
     def _property_getter(self):
-        raise SystemExit('This should not be called, ever!!!')
+        raise SystemExit("This should not be called, ever!!!")
 
 
 class NewStyleClassArgsLibrary:
@@ -23,7 +23,7 @@ class NewStyleClassArgsLibrary:
 class MyMetaClass(type):
 
     def __new__(cls, name, bases, ns):
-        ns['kw_created_by_metaclass'] = lambda self, arg: arg.upper()
+        ns["kw_created_by_metaclass"] = lambda self, arg: arg.upper()
         return type.__new__(cls, name, bases, ns)
 
     def method_in_metaclass(cls):
@@ -33,4 +33,4 @@ class MyMetaClass(type):
 class MetaClassLibrary(metaclass=MyMetaClass):
 
     def greet(self, name):
-        return 'Hello %s!' % name
+        return f"Hello {name}!"
