@@ -1,8 +1,10 @@
 class SomeObject:
     pass
 
+
 some_object = SomeObject()
-some_string = 'Hello, World!'
+some_string = "Hello, World!"
+
 
 def keyword():
     pass
