@@ -26,22 +26,29 @@ programmatic usage as follows:
     with command line argument processing.
   * :mod:`~robot.libdoc`: Module for library documentation generation.
   * :mod:`~robot.testdoc`: Module for test case documentation generation.
-  * :mod:`~robot.tidy`: Module for test data clean-up and format change.
 
 All the functions above can be imported like ``from robot import run``.
 Functions and classes provided by the modules need to be imported like
 ``from robot.libdoc import libdoc_cli``.
 
 The functions and modules listed above are considered stable. Other modules in
-this package are for for internal usage and may change without prior notice.
+this package are for internal usage and may change without prior notice.
 
 .. tip:: More public APIs are exposed by the :mod:`robot.api` package.
 """
 
-from robot.rebot import rebot, rebot_cli
-from robot.run import run, run_cli
+import sys
+import warnings
+
+from robot.rebot import rebot as rebot, rebot_cli as rebot_cli
+from robot.run import run as run, run_cli as run_cli
 from robot.version import get_version
 
+# Avoid warnings when using `python -m robot.run`.
+# https://github.com/robotframework/robotframework/issues/2552
+if not sys.warnoptions:
+    warnings.filterwarnings("ignore", category=RuntimeWarning, module="runpy")
 
-__all__ = ['run', 'run_cli', 'rebot', 'rebot_cli']
+
+__all__ = ["rebot", "rebot_cli", "run", "run_cli"]
 __version__ = get_version()
