@@ -1,4 +1,5 @@
-#  Copyright 2008-2013 Nokia Siemens Networks Oyj
+#  Copyright 2008-2015 Nokia Networks
+#  Copyright 2016-     Robot Framework Foundation
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -23,4 +24,10 @@ are likely to be rewritten at some point to be more convenient to use.
 Instantiating them is not likely to change, though.
 """
 
-from .settings import RobotSettings, RebotSettings
+from .languages import (
+    Language as Language,
+    LanguageLike as LanguageLike,
+    Languages as Languages,
+    LanguagesLike as LanguagesLike,
+)
+from .settings import RebotSettings as RebotSettings, RobotSettings as RobotSettings
