@@ -1,4 +1,5 @@
-#  Copyright 2008-2013 Nokia Siemens Networks Oyj
+#  Copyright 2008-2015 Nokia Networks
+#  Copyright 2016-     Robot Framework Foundation
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -14,13 +15,13 @@
 
 """Package for writing output files in HTML format.
 
-This package is considered stable but it is not part of the public API.
+This package is considered stable, but it is not part of the public API.
 """
 
-from .htmlfilewriter import HtmlFileWriter, ModelWriter
-from .jsonwriter import JsonWriter
+from .htmlfilewriter import HtmlFileWriter as HtmlFileWriter, ModelWriter as ModelWriter
+from .jsonwriter import JsonWriter as JsonWriter
 
-LOG = 'rebot/log.html'
-REPORT = 'rebot/report.html'
-LIBDOC = 'libdoc/libdoc.html'
-TESTDOC = 'testdoc/testdoc.html'
+LOG = "rebot/log.html"
+REPORT = "rebot/report.html"
+LIBDOC = "libdoc/libdoc.html"
+TESTDOC = "testdoc/testdoc.html"
