@@ -5,11 +5,17 @@ function toggleSuite(suiteId) {
 }
 
 function toggleTest(testId) {
-    toggleElement(testId, ['keyword']);
+    var test = window.testdata.findLoaded(testId);
+    var autoExpand = test.status == "FAIL" || test.status == "SKIP";
+    var closed = $('#' + testId).children('.element-header').hasClass('closed');
+    if (autoExpand && closed)
+        expandFailed(test);
+    else
+        toggleElement(testId, ['keyword']);
 }
 
 function toggleKeyword(kwId) {
-    toggleElement(kwId, ['keyword', 'message']);
+    toggleElement(kwId, ['keyword']);
 }
 
 function toggleElement(elementId, childrenNames) {
@@ -18,7 +24,8 @@ function toggleElement(elementId, childrenNames) {
     children.toggle(100, '', function () {
         element.children('.element-header').toggleClass('closed');
     });
-    populateChildren(elementId, children, childrenNames);
+    if (childrenNames)
+        populateChildren(elementId, children, childrenNames);
 }
 
 function populateChildren(elementId, childElement, childrenNames) {
@@ -34,14 +41,66 @@ function drawCallback(element, childElement, childrenNames) {
     return function () {
         util.map(childrenNames, function (childName) {
             var children = element[childName + 's']();
-            var template = childName + 'Template';
             util.map(children, function (child) {
-                $.tmpl(template, child).appendTo(childElement);
+                $.tmpl(child.template, child).appendTo(childElement);
             });
         });
     }
 }
 
+function expandSuite(suite) {
+    if (suite.status == "FAIL")
+        expandFailed(suite);
+    else
+        expandElement(suite);
+}
+
+function expandElement(item, retryCount) {
+    retryCount = typeof retryCount !== 'undefined' ? retryCount : 3;
+    var element = $('#' + item.id);
+    var children = element.children('.children');
+    // .css is faster than .show and .show w/ callback is terribly slow
+    children.css({'display': 'block'});
+    // in rare cases on large logs concurrent expanding fails => retry
+    if (children.css('display') != 'block' && retryCount > 0) {
+        console.debug('expandElement '+item.id+' failed! planning retry...');
+        setTimeout(function() { expandElement(item, retryCount-1); }, 0);
+        return;
+    }
+    populateChildren(item.id, children, item.childrenNames);
+    element.children('.element-header').removeClass('closed');
+}
+
+function expandElementWithId(elementid) {
+    expandElement(window.testdata.findLoaded(elementid));
+}
+
+function expandElementsWithIds(ids) {
+    util.map(ids, expandElementWithId);
+}
+
+function loadAndExpandElementIds(ids) {
+    for (var i in ids) {
+        window.testdata.ensureLoaded(ids[i], expandElementsWithIds);
+    }
+}
+
+function expandFailed(element) {
+    if (element.status == "FAIL" || (element.type == "test" && element.status == "SKIP")) {
+        window.elementsToExpand = [element];
+        window.expandDecider = function (e) {
+            return e.status == "FAIL";
+        };
+        expandRecursively();
+    }
+}
+
+function expandAll(elementId) {
+    window.elementsToExpand = [window.testdata.findLoaded(elementId)];
+    window.expandDecider = function () { return true; };
+    expandRecursively();
+}
+
 function expandRecursively() {
     if (!window.elementsToExpand.length)
         return;
@@ -54,53 +113,24 @@ function expandRecursively() {
     element.callWhenChildrenReady(function () {
         var children = element.children();
         for (var i = children.length-1; i >= 0; i--) {
-            if (window.expandDecider(children[i]))
-                window.elementsToExpand.push(children[i]);
+            var child = children[i];
+            if (child.type != 'message' && window.expandDecider(child))
+                window.elementsToExpand.push(child);
         }
         if (window.elementsToExpand.length)
             setTimeout(expandRecursively, 0);
     });
 }
 
-function expandElement(item) {
-    var element = $('#' + item.id);
-    var children = element.children('.children');
-    // .css is faster than .show and .show w/ callback is terribly slow
-    children.css({'display': 'block'});
-    populateChildren(item.id, children, item.childrenNames);
-    element.children('.element-header').removeClass('closed');
-}
-
-function expandElementWithId(elementid) {
-    expandElement(window.testdata.findLoaded(elementid));
-}
-
-function elementHiddenByUser(elementId) {
-    var element = $("#"+elementId);
+function elementHiddenByUser(id) {
+    var element = $('#' + id);
     return !element.is(":visible");
 }
 
-function expandAllChildren(elementId) {
-    window.elementsToExpand = [window.testdata.findLoaded(elementId)];
-    window.expandDecider = function () { return true; };
-    expandRecursively();
-}
-
-function expandCriticalFailed(element) {
-    if (element.status == "FAIL") {
-        window.elementsToExpand = [element];
-        window.expandDecider = function (e) {
-            return e.status == "FAIL" && (e.isCritical === undefined || e.isCritical);
-        };
-        expandRecursively();
-    }
-}
-
-function expandSuite(suite) {
-    if (suite.status == "PASS")
-        expandElement(suite);
-    else
-        expandCriticalFailed(suite);
+function collapseAll(id) {
+    var element = $('#' + id);
+    element.find('.children').css({'display': 'none'});
+    element.find('.element-header').addClass('closed');
 }
 
 function logLevelSelected(level) {
