@@ -5,6 +5,8 @@ window.model = (function () {
         suite.source = data.source;
         suite.relativeSource = data.relativeSource;
         suite.fullName = data.parent ? data.parent.fullName + '.' + data.name : data.name;
+        suite.type = 'suite';
+        suite.template = 'suiteTemplate';
         setStats(suite, data.statistics);
         suite.metadata = data.metadata;
         suite.populateKeywords = createIterablePopulator('Keyword');
@@ -12,7 +14,6 @@ window.model = (function () {
         suite.populateSuites = createIterablePopulator('Suite');
         suite.childrenNames = ['keyword', 'suite', 'test'];
         suite.callWhenChildrenReady = function (callable) { callable(); };
-        suite.message = data.message;
         suite.children = function () {
             return suite.keywords().concat(suite.tests()).concat(suite.suites());
         };
@@ -49,11 +50,6 @@ window.model = (function () {
                 return true;
             });
         };
-        suite.criticalTests = function () {
-            return suite.searchTests(function (test) {
-                return test.isCritical;
-            });
-        };
         return suite;
     }
 
@@ -113,6 +109,7 @@ window.model = (function () {
             name: data.name,
             doc: data.doc,
             status: data.status,
+            message: data.message,
             times: data.times,
             id: data.parent ? data.parent.id + '-' + data.id : data.id
         };
@@ -120,6 +117,8 @@ window.model = (function () {
 
     function Test(data) {
         var test = createModelObject(data);
+        test.type = 'test';
+        test.template = 'testTemplate';
         test.fullName = data.parent.fullName + '.' + test.name;
         test.formatParentName = function () { return util.formatParentName(test); };
         test.timeout = data.timeout;
@@ -131,9 +130,7 @@ window.model = (function () {
             if (test.isChildrenLoaded)
                 return test.keywords();
         };
-        test.isCritical = data.isCritical;
         test.tags = data.tags;
-        test.message = data.message;
         test.matchesTagPattern = function (pattern) {
             return containsTagPattern(test.tags, pattern);
         };
@@ -146,14 +143,15 @@ window.model = (function () {
     function Keyword(data) {
         var kw = createModelObject(data);
         kw.libname = data.libname;
+        kw.fullName = (kw.libname ? kw.libname + '.' : '') + kw.name;
         kw.type = data.type;
+        kw.template = 'keywordTemplate';
         kw.arguments = data.args;
-        kw.assign = data.assign + (data.assign ? ' =' : '');
+        kw.assign = data.assign;
         kw.tags = data.tags;
         kw.timeout = data.timeout;
-        kw.populateMessages = createIterablePopulator('Message');
         kw.populateKeywords = createIterablePopulator('Keyword');
-        kw.childrenNames = ['keyword', 'message'];
+        kw.childrenNames = ['keyword'];
         kw.isChildrenLoaded = data.isChildrenLoaded;
         kw.callWhenChildrenReady = window.fileLoading.getCallbackHandlerForKeywords(kw);
         kw.children = function () {
@@ -164,13 +162,17 @@ window.model = (function () {
     }
 
     function Message(level, date, text, link) {
-        return {
+        var message = {
+            type: 'message',
+            template: 'messageTemplate',
             level: level,
             time: util.timeFromDate(date),
             date: util.dateFromDate(date),
             text: text,
             link: link
         };
+        message.callWhenChildrenReady = function (callable) { callable(); };
+        return message;
     }
 
     function Times(timedata) {
@@ -229,19 +231,21 @@ window.stats = (function () {
     }
 
     function statElem(stat) {
-        stat.total = stat.pass + stat.fail;
-        var percents = calculatePercents(stat.total, stat.pass, stat.fail);
+        stat.total = stat.pass + stat.fail + stat.skip;
+        var percents = calculatePercents(stat.total, stat.pass, stat.fail, stat.skip);
         stat.passPercent = percents[0];
-        stat.failPercent = percents[1];
-        var widths = calculateWidths(stat.passPercent, stat.failPercent);
+        stat.skipPercent = percents[1];
+        stat.failPercent = percents[2];
+        var widths = calculateWidths(stat.passPercent, stat.skipPercent, stat.failPercent);
         stat.passWidth = widths[0];
-        stat.failWidth = widths[1];
+        stat.skipWidth = widths[1];
+        stat.failWidth = widths[2];
         return stat;
     }
 
     function totalStatElem(data) {
         var stat = statElem(data);
-        stat.type = stat.label == 'Critical Tests' ? 'critical' : 'all';
+        stat.type = 'all';
         return stat;
     }
 
@@ -255,9 +259,6 @@ window.stats = (function () {
         var stat = statElem(data);
         stat.fullName = stat.label;
         stat.formatParentName = function () { return util.formatParentName(stat); };
-        // compatibility with RF 2.5 outputs
-        if (!stat.name)
-            stat.name = stat.label.split('.').pop();
         return stat;
     }
 
@@ -270,34 +271,51 @@ window.stats = (function () {
             });
     }
 
-    function calculatePercents(total, passed, failed) {
+    function calculatePercents(total, passed, failed, skipped) {
         if (total == 0)
-            return [0.0, 0.0];
+            return [0.0, 0.0, 0.0];
         var pass = 100.0 * passed / total;
+        var skip = 100.0 * skipped / total;
         var fail = 100.0 * failed / total;
         if (pass > 0 && pass < 0.1)
-            return [0.1, 99.9];
+            pass = 0.1;
         if (fail > 0 && fail < 0.1)
-            return [99.9, 0.1];
-        return [Math.round(pass*10)/10, Math.round(fail*10)/10];
+            fail = 0.1;
+        if (skip > 0 && skip < 0.1)
+            skip = 0.1;
+        if (pass > 99.95 && pass < 100)
+            pass = 99.9;
+        if (fail > 99.95 && fail < 100)
+            fail = 99.9;
+        if (skip > 99.95 && skip < 100)
+            skip = 99.9;
+        return [round1(pass), round1(skip), round1(fail)];
     }
 
-    function calculateWidths(num1, num2) {
-        if (num1 + num2 == 0)
-            return [0.0, 0.0];
+    function calculateWidths(num1, num2, num3) {
+        if (num1 + num2 + num3 === 0)
+            return [0.0, 0.0, 0.0];
         // Make small percentages better visible
         if (num1 > 0 && num1 < 1)
-            return [1.0, 99.0];
+            num1 = 1.0;
         if (num2 > 0 && num2 < 1)
-            return [99.0, 1.0];
-        // Handle situation where both are rounded up
-        while (num1 + num2 > 100) {
-            if (num1 > num2)
-                num1 -= 0.1;
-            if (num2 > num1)
-                num2 -= 0.1;
+            num2 = 1.0;
+        if (num3 > 0 && num3 < 1)
+            num3 = 1.0;
+        // Handle situation where some are rounded up
+        while (num1 + num2 + num3 > 100) {
+            if (num1 >= num2 && num1 >= num3)
+                num1 = round1(num1 - 0.1);
+            else if (num2 >= num1 && num2 >= num3)
+                num2 = round1(num2 - 0.1);
+            else
+                num3 = round1(num3 - 0.1);
         }
-        return [num1, num2];
+        return [num1, num2, num3];
+    }
+
+    function round1(num) {
+        return Math.round(num*10) / 10;
     }
 
     return {
