@@ -13,7 +13,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-"""A test library for handling date and time values.
+"""A library for handling date and time values.
 
 ``DateTime`` is a Robot Framework standard library that supports creating and
 converting date and time values (e.g. `Get Current Date`, `Convert Time`),
@@ -21,37 +21,29 @@ as well as doing simple calculations with them (e.g. `Subtract Time From Date`,
 `Add Time To Time`). It supports dates and times in various formats, and can
 also be used by other libraries programmatically.
 
-This library is new in Robot Framework 2.8.5.
+== Table of contents ==
 
-= Table of Contents =
-
-- `Terminology`
-- `Date formats`
-- `Time formats`
-- `Millisecond handling`
-- `Programmatic usage`
-- `Shortcuts`
-- `Keywords`
+%TOC%
 
 = Terminology =
 
-In the context of this library, ``date`` and ``time`` generally have following
+In the context of this library, ``date`` and ``time`` generally have the following
 meanings:
 
 - ``date``: An entity with both date and time components but without any
-   timezone information. For example, ``2014-06-11 10:07:42``.
+   time zone information. For example, ``2014-06-11 10:07:42``.
 - ``time``: A time interval. For example, ``1 hour 20 minutes`` or ``01:20:00``.
 
 This terminology differs from what Python's standard
-[https://docs.python.org/2/library/datetime.html|datetime] module uses.
+[http://docs.python.org/library/datetime.html|datetime] module uses.
 Basically its
-[https://docs.python.org/2/library/datetime.html#datetime-objects|datetime] and
-[https://docs.python.org/2/library/datetime.html#timedelta-objects|timedelta]
+[http://docs.python.org/library/datetime.html#datetime-objects|datetime] and
+[http://docs.python.org/library/datetime.html#timedelta-objects|timedelta]
 objects match ``date`` and ``time`` as defined by this library.
 
 = Date formats =
 
-Dates can given to and received from keywords in `timestamp`, `custom
+Dates can be given to and received from keywords in `timestamp`, `custom
 timestamp`, `Python datetime` and `epoch time` formats. These formats are
 discussed thoroughly in subsequent sections.
 
@@ -86,8 +78,8 @@ Examples:
 
 It is possible to use custom timestamps in both input and output.
 The custom format is same as accepted by Python's
-[https://docs.python.org/2/library/datetime.html#strftime-strptime-behavior|
-datatime.strptime] function. For example, the default timestamp discussed
+[http://docs.python.org/library/datetime.html#strftime-strptime-behavior|
+datetime.strptime] function. For example, the default timestamp discussed
 in the previous section would match ``%Y-%m-%d %H:%M:%S.%f``.
 
 When using a custom timestamp in input, it must be specified using
@@ -101,16 +93,13 @@ Examples:
 | ${date} =       | Convert Date | ${date}                 | result_format=%d.%m.%Y |
 | Should Be Equal | ${date}      | 28.05.2014              |
 
-Notice that locale aware directives like ``%b``  do not work correctly with
-Jython on non-English locales: http://bugs.jython.org/issue2285
-
 == Python datetime ==
 
 Python's standard
-[https://docs.python.org/2/library/datetime.html#datetime.datetime|datetime]
-objects can be used both in input and output. In input they are recognized
-automatically, and in output it is possible to get them by giving ``datetime``
-value to ``result_format`` argument.
+[https://docs.python.org/library/datetime.html#datetime.datetime|datetime]
+objects can be used both in input and output. In input, they are recognized
+automatically, and in output it is possible to get them by using the ``datetime``
+value with the ``result_format`` argument.
 
 One nice benefit with datetime objects is that they have different time
 components available as attributes that can be easily accessed using the
@@ -126,21 +115,33 @@ Examples:
 | Should Be Equal As Integers | ${datetime.second}      | 42     |
 | Should Be Equal As Integers | ${datetime.microsecond} | 123000 |
 
+== Python date ==
+
+Python's standard [https://docs.python.org/library/datetime.html#datetime.date|date]
+objects are automatically recognized in input starting from Robot Framework 7.0.
+They are not supported in output, but ``datetime`` objects can be converted
+to ``date`` objects if needed:
+
+| ${datetime} = | Convert Date | 2023-12-18 11:10:42 | datetime |
+| Log | ${datetime.date()} | # The time part is ignored. |
+
 == Epoch time ==
 
 Epoch time is the time in seconds since the
 [http://en.wikipedia.org/wiki/Unix_time|UNIX epoch] i.e. 00:00:00.000 (UTC)
-1 January 1970. To give a date in epoch time, it must be given as a number
-(integer or float), not as a string. To return a date in epoch time,
+January 1, 1970. To give a date as an epoch time, it must be given as a number
+(integer or float), not as a string. To return a date as an epoch time,
 it is possible to use ``epoch`` value with ``result_format`` argument.
-Epoch time is returned as a floating point number.
+Epoch times are returned as floating point numbers.
 
-Notice that epoch time itself is independent on timezones and thus same
-around the world at a certain time. What local time a certain epoch time
-matches obviously then depends on the timezone. For example, examples below
-were tested in Finland but verifications would fail on other timezones.
+Notice that epoch times are independent on time zones and thus same
+around the world at a certain time. For example, epoch times returned
+by `Get Current Date` are not affected by the ``time_zone`` argument.
+What local time a certain epoch time matches then depends on the time zone.
+
+Following examples demonstrate using epoch times. They are tested in Finland,
+and due to the reasons explained above they would fail on other time zones.
 
-Examples:
 | ${date} =       | Convert Date | ${1000000000}           |
 | Should Be Equal | ${date}      | 2001-09-09 04:46:40.000 |
 | ${date} =       | Convert Date | 2014-06-12 13:27:59.279 | epoch |
@@ -149,16 +150,13 @@ Examples:
 == Earliest supported date ==
 
 The earliest date that is supported depends on the date format and to some
-extend on the platform:
+extent on the platform:
 
 - Timestamps support year 1900 and above.
 - Python datetime objects support year 1 and above.
-- Epoch time supports 1970 and above on Windows with Python and IronPython.
+- Epoch time supports 1970 and above on Windows.
 - On other platforms epoch time supports 1900 and above or even earlier.
 
-Prior to Robot Framework 2.9.2, all formats had same limitation as epoch time
-has nowadays.
-
 = Time formats =
 
 Similarly as dates, times can be given to and received from keywords in
@@ -193,17 +191,20 @@ integers or floating point numbers, the whole format is case and space
 insensitive, and it is possible to add a minus prefix to specify negative
 times. The available time specifiers are:
 
+- ``weeks``, ``week``, ``w`` (new in RF 7.1)
 - ``days``, ``day``, ``d``
 - ``hours``, ``hour``, ``h``
 - ``minutes``, ``minute``, ``mins``, ``min``, ``m``
 - ``seconds``, ``second``, ``secs``, ``sec``, ``s``
 - ``milliseconds``, ``millisecond``, ``millis``, ``ms``
+- ``microseconds``, ``microsecond``, ``us``, ``μs`` (new in RF 6.0)
+- ``nanoseconds``, ``nanosecond``, ``ns`` (new in RF 6.0)
 
 When returning a time string, it is possible to select between ``verbose``
 and ``compact`` representations using ``result_format`` argument. The verbose
-format uses long specifiers ``day``, ``hour``, ``minute``, ``second`` and
+format uses long specifiers ``week``, ``day``, ``hour``, ``minute``, ``second`` and
 ``millisecond``, and adds ``s`` at the end when needed. The compact format uses
-shorter specifiers ``d``, ``h``, ``min``, ``s`` and ``ms``, and even drops
+shorter specifiers ``w``, ``d``, ``h``, ``min``, ``s`` and ``ms``, and even drops
 the space between the number and the specifier.
 
 Examples:
@@ -239,7 +240,7 @@ Examples:
 == Python timedelta ==
 
 Python's standard
-[https://docs.python.org/2/library/datetime.html#datetime.timedelta|timedelta]
+[http://docs.python.org/library/datetime.html#datetime.timedelta|timedelta]
 objects are also supported both in input and in output. In input they are
 recognized automatically, and in output it is possible to receive them by
 giving ``timedelta`` value to ``result_format`` argument.
@@ -258,10 +259,9 @@ may also be included even if there would be none.
 All keywords returning dates or times have an option to leave milliseconds out
 by giving a true value to ``exclude_millis`` argument. If the argument is given
 as a string, it is considered true unless it is empty or case-insensitively
-equal to ``false`` or ``no``. Other argument types are tested using same
-[http://docs.python.org/2/library/stdtypes.html#truth-value-testing|rules as in
-Python]. Notice that prior to Robot Framework 2.9, all strings except the empty
-string were considered true.
+equal to ``false``, ``none`` or ``no``. Other argument types are tested using
+same [http://docs.python.org/library/stdtypes.html#truth|rules as in
+Python].
 
 When milliseconds are excluded, seconds in returned dates and times are
 rounded to the nearest full second. With `timestamp` and `timer string`
@@ -294,7 +294,7 @@ are available as functions that can be easily imported:
 |     seconds = convert_time(timeout)
 |     # ...
 
-Additionally helper classes ``Date`` and ``Time`` can be used directly:
+Additionally, helper classes ``Date`` and ``Time`` can be used directly:
 
 | from robot.libraries.DateTime import Date, Time
 |
@@ -304,28 +304,48 @@ Additionally helper classes ``Date`` and ``Time`` can be used directly:
 |     # ...
 """
 
-from datetime import datetime, timedelta
+import datetime
+import sys
 import time
-import re
+from typing import Literal, Union
 
+from robot.utils import (
+    elapsed_time_to_string, secs_to_timestr, timestr_to_secs, type_name
+)
 from robot.version import get_version
-from robot.utils import (elapsed_time_to_string, is_falsy, is_number,
-                         is_string, roundup, secs_to_timestr, timestr_to_secs,
-                         type_name, IRONPYTHON)
 
 __version__ = get_version()
-__all__ = ['convert_time', 'convert_date', 'subtract_date_from_date',
-           'subtract_time_from_date', 'subtract_time_from_time',
-           'add_time_to_time', 'add_time_to_date', 'get_current_date']
+__all__ = [
+    "add_time_to_date",
+    "add_time_to_time",
+    "convert_date",
+    "convert_time",
+    "get_current_date",
+    "subtract_date_from_date",
+    "subtract_time_from_date",
+    "subtract_time_from_time",
+]
+
+DateInput = Union[datetime.datetime, datetime.date, float, int, str]
+DateOutput = Union[datetime.datetime, float, str]
+DateFormat = Union[Literal["timestamp", "datetime", "epoch"], str]
+TimeInput = Union[datetime.timedelta, float, int, str]
+TimeOutput = Union[datetime.timedelta, float, str]
+TimeFormat = Literal["number", "verbose", "compact", "timer", "timedelta"]
 
 
-def get_current_date(time_zone='local', increment=0,
-                     result_format='timestamp', exclude_millis=False):
+def get_current_date(
+    time_zone: Literal["local", "UTC"] = "local",
+    increment: TimeInput = 0,
+    result_format: DateFormat = "timestamp",
+    exclude_millis: bool = False,
+) -> DateOutput:
     """Returns current local or UTC time with an optional increment.
 
     Arguments:
     - ``time_zone:``      Get the current time on this time zone. Currently only
                           ``local`` (default) and ``UTC`` are supported.
+                          Has no effect if date is returned as an `epoch time`.
     - ``increment:``      Optional time increment to add to the returned date in
                           one of the supported `time formats`. Can be negative.
     - ``result_format:``  Format of the returned date (see `date formats`).
@@ -345,18 +365,27 @@ def get_current_date(time_zone='local', increment=0,
     | Should Be Equal | ${date.year}     | ${2014}                 |
     | Should Be Equal | ${date.month}    | ${6}                    |
     """
-    if time_zone.upper() == 'LOCAL':
-        dt = datetime.now()
-    elif time_zone.upper() == 'UTC':
-        dt = datetime.utcnow()
+    if time_zone.upper() == "LOCAL" or result_format.upper() == "EPOCH":
+        dt = datetime.datetime.now()
+    elif time_zone.upper() == "UTC":
+        if sys.version_info >= (3, 12):
+            # `utcnow()` was deprecated in Python 3.12. We only support "naive"
+            # datetime objects and thus need to remove timezone information here.
+            dt = datetime.datetime.now(datetime.UTC).replace(tzinfo=None)
+        else:
+            dt = datetime.datetime.utcnow()
     else:
-        raise ValueError("Unsupported timezone '%s'." % time_zone)
+        raise ValueError(f"Unsupported timezone '{time_zone}'.")
     date = Date(dt) + Time(increment)
-    return date.convert(result_format, millis=is_falsy(exclude_millis))
+    return date.convert(result_format, millis=not exclude_millis)
 
 
-def convert_date(date, result_format='timestamp', exclude_millis=False,
-                 date_format=None):
+def convert_date(
+    date: DateInput,
+    result_format: DateFormat = "timestamp",
+    exclude_millis: bool = False,
+    date_format: "str | None" = None,
+) -> DateOutput:
     """Converts between supported `date formats`.
 
     Arguments:
@@ -374,11 +403,14 @@ def convert_date(date, result_format='timestamp', exclude_millis=False,
     | ${date} =       | Convert Date | 5.28.2014 12:05         | exclude_millis=yes | date_format=%m.%d.%Y %H:%M |
     | Should Be Equal | ${date}      | 2014-05-28 12:05:00     |
     """
-    return Date(date, date_format).convert(result_format,
-                                           millis=is_falsy(exclude_millis))
+    return Date(date, date_format).convert(result_format, millis=not exclude_millis)
 
 
-def convert_time(time, result_format='number', exclude_millis=False):
+def convert_time(
+    time: TimeInput,
+    result_format: TimeFormat = "number",
+    exclude_millis: bool = False,
+) -> TimeOutput:
     """Converts between supported `time formats`.
 
     Arguments:
@@ -395,12 +427,17 @@ def convert_time(time, result_format='number', exclude_millis=False):
     | ${time} =       | Convert Time  | ${3661.5} | timer | exclude_milles=yes |
     | Should Be Equal | ${time}       | 01:01:02          |
     """
-    return Time(time).convert(result_format, millis=is_falsy(exclude_millis))
+    return Time(time).convert(result_format, millis=not exclude_millis)
 
 
-def subtract_date_from_date(date1, date2, result_format='number',
-                            exclude_millis=False, date1_format=None,
-                            date2_format=None):
+def subtract_date_from_date(
+    date1: DateInput,
+    date2: DateInput,
+    result_format: TimeFormat = "number",
+    exclude_millis: bool = False,
+    date1_format: "str | None" = None,
+    date2_format: "str | None" = None,
+) -> TimeOutput:
     """Subtracts date from another date and returns time between.
 
     Arguments:
@@ -421,11 +458,16 @@ def subtract_date_from_date(date1, date2, result_format='number',
     | Should Be Equal | ${time}                 | 1 day 42 seconds        |
     """
     time = Date(date1, date1_format) - Date(date2, date2_format)
-    return time.convert(result_format, millis=is_falsy(exclude_millis))
+    return time.convert(result_format, millis=not exclude_millis)
 
 
-def add_time_to_date(date, time, result_format='timestamp',
-                     exclude_millis=False, date_format=None):
+def add_time_to_date(
+    date: DateInput,
+    time: TimeInput,
+    result_format: DateFormat = "timestamp",
+    exclude_millis: bool = False,
+    date_format: "str | None" = None,
+) -> DateOutput:
     """Adds time to date and returns the resulting date.
 
     Arguments:
@@ -445,11 +487,16 @@ def add_time_to_date(date, time, result_format='timestamp',
     | Should Be Equal | ${date}          | 2014-05-28 13:07:06.115 |
     """
     date = Date(date, date_format) + Time(time)
-    return date.convert(result_format, millis=is_falsy(exclude_millis))
+    return date.convert(result_format, millis=not exclude_millis)
 
 
-def subtract_time_from_date(date, time, result_format='timestamp',
-                            exclude_millis=False, date_format=None):
+def subtract_time_from_date(
+    date: DateInput,
+    time: TimeInput,
+    result_format: DateFormat = "timestamp",
+    exclude_millis: bool = False,
+    date_format: "str | None" = None,
+) -> DateOutput:
     """Subtracts time from date and returns the resulting date.
 
     Arguments:
@@ -469,11 +516,15 @@ def subtract_time_from_date(date, time, result_format='timestamp',
     | Should Be Equal | ${date}                 | 2014-05-28 12:05:03.111 |
     """
     date = Date(date, date_format) - Time(time)
-    return date.convert(result_format, millis=is_falsy(exclude_millis))
+    return date.convert(result_format, millis=not exclude_millis)
 
 
-def add_time_to_time(time1, time2, result_format='number',
-                     exclude_millis=False):
+def add_time_to_time(
+    time1: TimeInput,
+    time2: TimeInput,
+    result_format: TimeFormat = "number",
+    exclude_millis: bool = False,
+) -> TimeOutput:
     """Adds time to another time and returns the resulting time.
 
     Arguments:
@@ -490,11 +541,15 @@ def add_time_to_time(time1, time2, result_format='number',
     | Should Be Equal | ${time}          | 04:07:03          |
     """
     time = Time(time1) + Time(time2)
-    return time.convert(result_format, millis=is_falsy(exclude_millis))
+    return time.convert(result_format, millis=not exclude_millis)
 
 
-def subtract_time_from_time(time1, time2, result_format='number',
-                            exclude_millis=False):
+def subtract_time_from_time(
+    time1: TimeInput,
+    time2: TimeInput,
+    result_format: TimeFormat = "number",
+    exclude_millis: bool = False,
+) -> TimeOutput:
     """Subtracts time from another time and returns the resulting time.
 
     Arguments:
@@ -512,167 +567,147 @@ def subtract_time_from_time(time1, time2, result_format='number',
     | Should Be Equal | ${time}                 | - 10s    |
     """
     time = Time(time1) - Time(time2)
-    return time.convert(result_format, millis=is_falsy(exclude_millis))
+    return time.convert(result_format, millis=not exclude_millis)
 
 
-class Date(object):
+class Date:
 
-    def __init__(self, date, input_format=None):
+    def __init__(
+        self,
+        date: DateInput,
+        input_format: "str | None" = None,
+    ):
         self.datetime = self._convert_to_datetime(date, input_format)
 
     @property
-    def seconds(self):
+    def seconds(self) -> float:
         # Mainly for backwards compatibility with RF 2.9.1 and earlier.
         return self._convert_to_epoch(self.datetime)
 
-    def _convert_to_datetime(self, date, input_format):
-        if isinstance(date, datetime):
+    def _convert_to_datetime(
+        self,
+        date: DateInput,
+        input_format: "str | None",
+    ) -> datetime.datetime:
+        if isinstance(date, datetime.datetime):
             return date
-        if is_number(date):
-            return self._seconds_to_datetime(date)
-        if is_string(date):
+        if isinstance(date, datetime.date):
+            return datetime.datetime(date.year, date.month, date.day)
+        if isinstance(date, (int, float)):
+            return self._epoch_seconds_to_datetime(date)
+        if isinstance(date, str):
             return self._string_to_datetime(date, input_format)
-        raise ValueError("Unsupported input '%s'." % date)
+        raise ValueError(f"Unsupported input '{date}'.")
 
-    def _seconds_to_datetime(self, secs):
-        # Workaround microsecond rounding errors with IronPython:
-        # https://github.com/IronLanguages/main/issues/1170
-        # Also Jython had similar problems, but they seem to be fixed in 2.7.
-        dt = datetime.fromtimestamp(secs)
-        return dt.replace(microsecond=roundup(secs % 1 * 1e6))
+    def _epoch_seconds_to_datetime(self, secs: float) -> datetime.datetime:
+        return datetime.datetime.fromtimestamp(secs)
 
-    def _string_to_datetime(self, ts, input_format):
+    def _string_to_datetime(
+        self,
+        timestamp: str,
+        input_format: "str | None",
+    ) -> datetime.datetime:
         if not input_format:
-            ts = self._normalize_timestamp(ts)
-            input_format = '%Y-%m-%d %H:%M:%S.%f'
-        if self._need_to_handle_f_directive(input_format):
-            return self._handle_un_supported_f_directive(ts, input_format)
-        return datetime.strptime(ts, input_format)
+            timestamp = self._normalize_timestamp(timestamp)
+            input_format = "%Y-%m-%d %H:%M:%S.%f"
+        return datetime.datetime.strptime(timestamp, input_format)
 
-    def _normalize_timestamp(self, date):
-        ts = ''.join(d for d in date if d.isdigit())
-        if len(ts) < 8:
-            raise ValueError("Invalid timestamp '%s'." % date)
-        ts = ts.ljust(20, '0')
-        return '%s-%s-%s %s:%s:%s.%s' % (ts[:4], ts[4:6], ts[6:8], ts[8:10],
-                                         ts[10:12], ts[12:14], ts[14:])
+    def _normalize_timestamp(self, timestamp: str) -> str:
+        numbers = "".join(d for d in timestamp if d.isdigit())
+        if not (8 <= len(numbers) <= 20):
+            raise ValueError(f"Invalid timestamp '{timestamp}'.")
+        d = numbers[:8]
+        t = numbers[8:].ljust(12, "0")
+        return f"{d[:4]}-{d[4:6]}-{d[6:8]} {t[:2]}:{t[2:4]}:{t[4:6]}.{t[6:]}"
 
-    def _need_to_handle_f_directive(self, format):
-        # https://github.com/IronLanguages/main/issues/1169
-        return IRONPYTHON and '%f' in format
-
-    def _handle_un_supported_f_directive(self, ts, input_format):
-        input_format = self._remove_f_from_format(input_format)
-        match = re.search('\d+$', ts)
-        if not match:
-            raise ValueError("time data '%s' does not match format '%s%%f'."
-                             % (ts, input_format))
-        end_digits = match.group(0)
-        micro = int(end_digits.ljust(6, '0'))
-        dt = datetime.strptime(ts[:-len(end_digits)], input_format)
-        return dt.replace(microsecond=micro)
-
-    def _remove_f_from_format(self, format):
-        if not format.endswith('%f'):
-            raise ValueError('%f directive is supported only at the end of '
-                             'the format string on this Python interpreter.')
-        return format[:-2]
-
-    def convert(self, format, millis=True):
+    def convert(self, format: str, millis: bool = True) -> DateOutput:
         dt = self.datetime
         if not millis:
             secs = 1 if dt.microsecond >= 5e5 else 0
-            dt = dt.replace(microsecond=0) + timedelta(seconds=secs)
-        if '%' in format:
+            dt = dt.replace(microsecond=0) + datetime.timedelta(seconds=secs)
+        if "%" in format:
             return self._convert_to_custom_timestamp(dt, format)
         format = format.lower()
-        if format == 'timestamp':
+        if format == "timestamp":
             return self._convert_to_timestamp(dt, millis)
-        if format == 'datetime':
+        if format == "datetime":
             return dt
-        if format == 'epoch':
+        if format == "epoch":
             return self._convert_to_epoch(dt)
-        raise ValueError("Unknown format '%s'." % format)
+        raise ValueError(f"Unknown format '{format}'.")
 
-    def _convert_to_custom_timestamp(self, dt, format):
-        if not self._need_to_handle_f_directive(format):
-            return dt.strftime(format)
-        format = self._remove_f_from_format(format)
-        return dt.strftime(format) + '%06d' % dt.microsecond
+    def _convert_to_custom_timestamp(self, dt: datetime.datetime, format: str) -> str:
+        return dt.strftime(format)
 
-    def _convert_to_timestamp(self, dt, millis=True):
+    def _convert_to_timestamp(self, dt: datetime.datetime, millis: bool = True) -> str:
         if not millis:
-            return dt.strftime('%Y-%m-%d %H:%M:%S')
-        ms = roundup(dt.microsecond / 1000.0)
+            return dt.strftime("%Y-%m-%d %H:%M:%S")
+        ms = round(dt.microsecond / 1000)
         if ms == 1000:
-            dt += timedelta(seconds=1)
+            dt += datetime.timedelta(seconds=1)
             ms = 0
-        return dt.strftime('%Y-%m-%d %H:%M:%S') + '.%03d' % ms
+        return dt.strftime("%Y-%m-%d %H:%M:%S") + f".{ms:03d}"
 
-    def _convert_to_epoch(self, dt):
-        return time.mktime(dt.timetuple()) + dt.microsecond / 1e6
+    def _convert_to_epoch(self, dt: datetime.datetime) -> float:
+        try:
+            return dt.timestamp()
+        except OSError:
+            # https://github.com/python/cpython/issues/81708
+            return time.mktime(dt.timetuple()) + dt.microsecond / 1e6
 
-    def __add__(self, other):
+    def __add__(self, other: "Time") -> "Date":
         if isinstance(other, Time):
             return Date(self.datetime + other.timedelta)
-        raise TypeError('Can only add Time to Date, got %s.' % type_name(other))
+        raise TypeError(f"Can only add Time to Date, got {type_name(other)}.")
 
-    def __sub__(self, other):
+    def __sub__(self, other: "Date | Time") -> "Date | Time":
         if isinstance(other, Date):
             return Time(self.datetime - other.datetime)
         if isinstance(other, Time):
             return Date(self.datetime - other.timedelta)
-        raise TypeError('Can only subtract Date or Time from Date, got %s.'
-                        % type_name(other))
+        raise TypeError(
+            f"Can only subtract Date or Time from Date, got {type_name(other)}."
+        )
 
 
-class Time(object):
+class Time:
 
-    def __init__(self, time):
-        self.seconds = float(self._convert_time_to_seconds(time))
-
-    def _convert_time_to_seconds(self, time):
-        if isinstance(time, timedelta):
-            # timedelta.total_seconds() is new in Python 2.7
-            return (time.days * 24 * 60 * 60 +
-                    time.seconds +
-                    time.microseconds / 1e6)
-        return timestr_to_secs(time, round_to=None)
+    def __init__(self, time: TimeInput):
+        self.seconds = timestr_to_secs(time, round_to=None)
 
     @property
-    def timedelta(self):
-        return timedelta(seconds=self.seconds)
+    def timedelta(self) -> datetime.timedelta:
+        return datetime.timedelta(seconds=self.seconds)
 
-    def convert(self, format, millis=True):
+    def convert(self, format: str, millis: bool = True) -> TimeOutput:
         try:
-            result_converter = getattr(self, '_convert_to_%s' % format.lower())
+            result_converter = getattr(self, f"_convert_to_{format.lower()}")
         except AttributeError:
-            raise ValueError("Unknown format '%s'." % format)
-        seconds = self.seconds if millis else float(roundup(self.seconds))
+            raise ValueError(f"Unknown format '{format}'.")
+        seconds = self.seconds if millis else float(round(self.seconds))
         return result_converter(seconds, millis)
 
-    def _convert_to_number(self, seconds, millis=True):
+    def _convert_to_number(self, seconds: float, _) -> float:
         return seconds
 
-    def _convert_to_verbose(self, seconds, millis=True):
+    def _convert_to_verbose(self, seconds: float, _) -> str:
         return secs_to_timestr(seconds)
 
-    def _convert_to_compact(self, seconds, millis=True):
+    def _convert_to_compact(self, seconds: float, _) -> str:
         return secs_to_timestr(seconds, compact=True)
 
-    def _convert_to_timer(self, seconds, millis=True):
-        return elapsed_time_to_string(seconds * 1000, include_millis=millis)
+    def _convert_to_timer(self, seconds: float, millis: bool = True) -> str:
+        return elapsed_time_to_string(seconds, include_millis=millis, seconds=True)
 
-    def _convert_to_timedelta(self, seconds, millis=True):
-        return timedelta(seconds=seconds)
+    def _convert_to_timedelta(self, seconds: float, _) -> datetime.timedelta:
+        return datetime.timedelta(seconds=seconds)
 
-    def __add__(self, other):
+    def __add__(self, other: "Time") -> "Time":
         if isinstance(other, Time):
             return Time(self.seconds + other.seconds)
-        raise TypeError('Can only add Time to Time, got %s.' % type_name(other))
+        raise TypeError(f"Can only add Time to Time, got {type_name(other)}.")
 
-    def __sub__(self, other):
+    def __sub__(self, other: "Time") -> "Time":
         if isinstance(other, Time):
             return Time(self.seconds - other.seconds)
-        raise TypeError('Can only subtract Time from Time, got %s.'
-                        % type_name(other))
+        raise TypeError(f"Can only subtract Time from Time, got {type_name(other)}.")
