@@ -1,4 +1,5 @@
-#  Copyright 2008-2013 Nokia Siemens Networks Oyj
+#  Copyright 2008-2015 Nokia Networks
+#  Copyright 2016-     Robot Framework Foundation
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -12,7 +13,18 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from robot.api import logger
+
+
 def none_shall_pass(who):
     if who is not None:
-        raise AssertionError('None shall pass!')
-    print '*HTML* <object width="480" height="385"><param name="movie" value="http://www.youtube.com/v/dhRUe-gz690&hl=en_US&fs=1&rel=0&color1=0x234900&color2=0x4e9e00"></param><param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param><embed src="http://www.youtube.com/v/dhRUe-gz690&hl=en_US&fs=1&rel=0&color1=0x234900&color2=0x4e9e00" type="application/x-shockwave-flash" allowscriptaccess="always" allowfullscreen="true" width="480" height="385"></embed></object>'
+        raise AssertionError("None shall pass!")
+    logger.info(
+        '<iframe width="560" height="315" '
+        'src="https://www.youtube-nocookie.com/embed/zKhEw7nD9C4?autoplay=1" '
+        'frameborder="0" '
+        'allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" '
+        "allowfullscreen>"
+        "</iframe>",
+        html=True,
+    )
