@@ -13,56 +13,70 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from collections.abc import Iterator
+
+from robot.utils import plural_or_not, test_or_task
+
 from .stats import TotalStat
 from .visitor import SuiteVisitor
 
 
-class TotalStatistics(object):
+class TotalStatistics:
     """Container for total statistics."""
 
-    def __init__(self):
-        #: Instance of :class:`~robot.model.stats.TotalStat` for critical tests.
-        self.critical = TotalStat('Critical Tests')
+    def __init__(self, rpa: bool = False):
         #: Instance of :class:`~robot.model.stats.TotalStat` for all the tests.
-        self.all = TotalStat('All Tests')
+        self.stat = TotalStat(test_or_task("All {Test}s", rpa))
+        self._rpa = rpa
 
     def visit(self, visitor):
-        visitor.visit_total_statistics(self)
+        visitor.visit_total_statistics(self.stat)
 
-    def __iter__(self):
-        return iter([self.critical, self.all])
+    def __iter__(self) -> "Iterator[TotalStat]":
+        yield self.stat
 
     @property
-    def message(self):
+    def total(self) -> int:
+        return self.stat.total
+
+    @property
+    def passed(self) -> int:
+        return self.stat.passed
+
+    @property
+    def skipped(self) -> int:
+        return self.stat.skipped
+
+    @property
+    def failed(self) -> int:
+        return self.stat.failed
+
+    def add_test(self, test):
+        self.stat.add_test(test)
+
+    @property
+    def message(self) -> str:
         """String representation of the statistics.
 
         For example::
-
-            2 critical tests, 1 passed, 1 failed
-            2 tests total, 1 passed, 1 failed
+            2 tests, 1 passed, 1 failed
         """
-        ctotal, cend, cpass, cfail = self._get_counts(self.critical)
-        atotal, aend, apass, afail = self._get_counts(self.all)
-        return ('%d critical test%s, %d passed, %d failed\n'
-                '%d test%s total, %d passed, %d failed'
-                % (ctotal, cend, cpass, cfail, atotal, aend, apass, afail))
-
-    def _get_counts(self, stat):
-        ending = 's' if stat.total != 1 else ''
-        return stat.total, ending, stat.passed, stat.failed
+        kind = test_or_task("test", self._rpa) + plural_or_not(self.total)
+        msg = f"{self.total} {kind}, {self.passed} passed, {self.failed} failed"
+        if self.skipped:
+            msg += f", {self.skipped} skipped"
+        return msg
 
 
 class TotalStatisticsBuilder(SuiteVisitor):
 
-    def __init__(self, suite=None):
-        self.stats = TotalStatistics()
+    def __init__(self, suite=None, rpa=False):
+        self.stats = TotalStatistics(rpa)
         if suite:
             suite.visit(self)
 
     def add_test(self, test):
-        self.stats.all.add_test(test)
-        if test.critical:
-            self.stats.critical.add_test(test)
+        self.stats.add_test(test)
 
     def visit_test(self, test):
         self.add_test(test)
