@@ -13,22 +13,25 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from os.path import basename, splitext
+from pathlib import Path
 
-from robot.htmldata import HtmlFileWriter, ModelWriter, LOG, REPORT
-from robot.utils import file_writer, is_string
+from robot.htmldata import HtmlFileWriter, LOG, ModelWriter, REPORT
+from robot.utils import file_writer
 
 from .jswriter import JsResultWriter, SplitLogWriter
 
 
-class _LogReportWriter(object):
+class _LogReportWriter:
+    usage = None
 
     def __init__(self, js_model):
         self._js_model = js_model
 
-    def _write_file(self, path, config, template):
-        outfile = file_writer(path) \
-            if is_string(path) else path  # unit test hook
+    def _write_file(self, path: Path, config, template):
+        if isinstance(path, Path):
+            outfile = file_writer(path, usage=self.usage)
+        else:
+            outfile = path  # unit test hook
         with outfile:
             model_writer = RobotModelWriter(outfile, self._js_model, config)
             writer = HtmlFileWriter(outfile, model_writer)
@@ -36,26 +39,32 @@ class _LogReportWriter(object):
 
 
 class LogWriter(_LogReportWriter):
+    usage = "log"
 
-    def write(self, path, config):
+    def write(self, path: "Path|str", config):
+        if isinstance(path, str):
+            path = Path(path)
         self._write_file(path, config, LOG)
         if self._js_model.split_results:
-            self._write_split_logs(splitext(path)[0])
+            self._write_split_logs(path)
 
-    def _write_split_logs(self, base):
-        for index, (keywords, strings) in enumerate(self._js_model.split_results):
-            index += 1  # enumerate accepts start index only in Py 2.6+
-            self._write_split_log(index, keywords, strings, '%s-%d.js' % (base, index))
+    def _write_split_logs(self, path: Path):
+        for index, (kws, strings) in enumerate(self._js_model.split_results, start=1):
+            name = f"{path.stem}-{index}.js"
+            self._write_split_log(index, kws, strings, path.with_name(name))
 
-    def _write_split_log(self, index, keywords, strings, path):
-        with file_writer(path) as outfile:
+    def _write_split_log(self, index, kws, strings, path: Path):
+        with file_writer(path, usage=self.usage) as outfile:
             writer = SplitLogWriter(outfile)
-            writer.write(keywords, strings, index, basename(path))
+            writer.write(kws, strings, index, path.name)
 
 
 class ReportWriter(_LogReportWriter):
+    usage = "report"
 
-    def write(self, path, config):
+    def write(self, path: "Path|str", config):
+        if isinstance(path, str):
+            path = Path(path)
         self._write_file(path, config, REPORT)
 
 
