@@ -13,26 +13,18 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from robot.output.xmllogger import XmlLogger
+from robot.output.xmllogger import LegacyXmlLogger, XmlLogger
 
 
 class OutputWriter(XmlLogger):
+    generator = "Rebot"
 
-    def __init__(self, output):
-        XmlLogger.__init__(self, output, generator='Rebot')
+    def end_result(self, result):
+        self.close()
 
-    def start_message(self, msg):
-        self._write_message(msg)
 
-    def visit_keyword(self, kw):
-        self.start_keyword(kw)
-        for child in kw.children:
-            child.visit(self)
-        self.end_keyword(kw)
-
-    def close(self):
-        self._writer.end('robot')
-        self._writer.close()
+class LegacyOutputWriter(LegacyXmlLogger):
+    generator = "Rebot"
 
     def end_result(self, result):
         self.close()
