@@ -18,14 +18,13 @@ from robot.errors import DataError
 from robot.model import ModelModifier
 from robot.output import LOGGER
 from robot.result import ExecutionResult, Result
-from robot.utils import unic
 
 from .jsmodelbuilders import JsModelBuilder
 from .logreportwriters import LogWriter, ReportWriter
 from .xunitwriter import XUnitWriter
 
 
-class ResultWriter(object):
+class ResultWriter:
     """A class to create log, report, output XML and xUnit files.
 
     :param sources: Either one :class:`~robot.result.executionresult.Result`
@@ -55,48 +54,41 @@ class ResultWriter(object):
         settings = settings or RebotSettings(options)
         results = Results(settings, *self._sources)
         if settings.output:
-            self._write_output(results.result, settings.output)
+            self._write_output(results.result, settings.output, settings.legacy_output)
         if settings.xunit:
-            self._write_xunit(results.result, settings.xunit,
-                              settings.xunit_skip_noncritical)
+            self._write_xunit(results.result, settings.xunit)
         if settings.log:
-            config = dict(settings.log_config,
-                          minLevel=results.js_result.min_level)
+            config = dict(settings.log_config, minLevel=results.js_result.min_level)
             self._write_log(results.js_result, settings.log, config)
         if settings.report:
             results.js_result.remove_data_not_needed_in_report()
-            self._write_report(results.js_result, settings.report,
-                               settings.report_config)
+            self._write_report(
+                results.js_result, settings.report, settings.report_config
+            )
         return results.return_code
 
-    def _write_output(self, result, path):
-        self._write('Output', result.save, path)
+    def _write_output(self, result, path, legacy_output=False):
+        self._write("Output", result.save, path, legacy_output)
 
-    def _write_xunit(self, result, path, skip_noncritical):
-        self._write('XUnit', XUnitWriter(result, skip_noncritical).write, path)
+    def _write_xunit(self, result, path):
+        self._write("XUnit", XUnitWriter(result).write, path)
 
     def _write_log(self, js_result, path, config):
-        self._write('Log', LogWriter(js_result).write, path, config)
+        self._write("Log", LogWriter(js_result).write, path, config)
 
     def _write_report(self, js_result, path, config):
-        self._write('Report', ReportWriter(js_result).write, path, config)
+        self._write("Report", ReportWriter(js_result).write, path, config)
 
     def _write(self, name, writer, path, *args):
         try:
             writer(path, *args)
         except DataError as err:
             LOGGER.error(err.message)
-        except EnvironmentError as err:
-            # `err.filename` can be different than `path` at least if reading
-            # log/report templates or writing split log fails.
-            # `unic` is needed due to http://bugs.jython.org/issue1825.
-            LOGGER.error("Writing %s file '%s' failed: %s: %s" %
-                         (name.lower(), path, err.strerror, unic(err.filename)))
         else:
-            LOGGER.output_file(name, path)
+            LOGGER.result_file(name, path)
 
 
-class Results(object):
+class Results:
 
     def __init__(self, settings, *sources):
         self._settings = settings
@@ -116,26 +108,39 @@ class Results(object):
         if self._result is None:
             include_keywords = bool(self._settings.log or self._settings.output)
             flattened = self._settings.flatten_keywords
-            self._result = ExecutionResult(include_keywords=include_keywords,
-                                           flattened_keywords=flattened,
-                                           merge=self._settings.merge,
-                                           *self._sources)
-            self._result.configure(self._settings.status_rc,
-                                   self._settings.suite_config,
-                                   self._settings.statistics_config)
-            modifier = ModelModifier(self._settings.pre_rebot_modifiers,
-                                     self._settings.process_empty_suite,
-                                     LOGGER)
-            self._result.suite.visit(modifier)
+            self._result = ExecutionResult(
+                *self._sources,
+                include_keywords=include_keywords,
+                flattened_keywords=flattened,
+                merge=self._settings.merge,
+                rpa=self._settings.rpa,
+            )
+            if self._settings.rpa is None:
+                self._settings.rpa = self._result.rpa
+            if self._settings.pre_rebot_modifiers:
+                modifier = ModelModifier(
+                    self._settings.pre_rebot_modifiers,
+                    self._settings.process_empty_suite,
+                    LOGGER,
+                )
+                self._result.suite.visit(modifier)
+            self._result.configure(
+                self._settings.status_rc,
+                self._settings.suite_config,
+                self._settings.statistics_config,
+            )
             self.return_code = self._result.return_code
         return self._result
 
     @property
     def js_result(self):
         if self._js_result is None:
-            builder = JsModelBuilder(log_path=self._settings.log,
-                                     split_log=self._settings.split_log,
-                                     prune_input_to_save_memory=self._prune)
+            builder = JsModelBuilder(
+                log_path=self._settings.log,
+                split_log=self._settings.split_log,
+                expand_keywords=self._settings.expand_keywords,
+                prune_input_to_save_memory=self._prune,
+            )
             self._js_result = builder.build_from(self.result)
             if self._prune:
                 self._result = None
