@@ -1,4 +1,5 @@
-#  Copyright 2008-2015 Nokia Solutions and Networks
+#  Copyright 2008-2015 Nokia Networks
+#  Copyright 2016-     Robot Framework Foundation
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -12,39 +13,45 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from robot.model import ItemList
+from typing import Iterator, Sequence
+
+from robot.model import ItemList, Message
 from robot.utils import setter
 
-from .message import Message
 
-
-class ExecutionErrors(object):
+class ExecutionErrors:
     """Represents errors occurred during the execution of tests.
 
     An error might be, for example, that importing a library has failed.
     """
-    message_class = Message
 
-    def __init__(self, messages=None):
-        #: A :class:`list-like object <robot.model.itemlist.ItemList>` of
-        #: :class:`~robot.model.message.Message` instances.
+    id = "errors"
+
+    def __init__(self, messages: Sequence[Message] = ()):
         self.messages = messages
 
     @setter
-    def messages(self, msgs):
-        return ItemList(self.message_class, items=msgs)
+    def messages(self, messages) -> ItemList[Message]:
+        return ItemList(Message, {"parent": self}, items=messages)
 
-    def add(self, other):
+    def add(self, other: "ExecutionErrors"):
         self.messages.extend(other.messages)
 
     def visit(self, visitor):
         visitor.visit_errors(self)
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator[Message]:
         return iter(self.messages)
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self.messages)
 
-    def __getitem__(self, index):
+    def __getitem__(self, index) -> Message:
         return self.messages[index]
+
+    def __str__(self) -> str:
+        if not self:
+            return "No execution errors"
+        if len(self) == 1:
+            return f"Execution error: {self[0]}"
+        return "\n".join(["Execution errors:"] + ["- " + str(m) for m in self])
