@@ -14,12 +14,13 @@
 #  limitations under the License.
 
 import os
+import re
 import tempfile
 
-from robot.errors import VariableError
+from robot.errors import DataError
 from robot.model import Tags
 from robot.output import LOGGER
-from robot.utils import abspath, find_file, get_error_details, DotDict, NormalizedDict
+from robot.utils import abspath, DotDict, find_file, get_error_details, NormalizedDict
 
 from .resolvable import GlobalVariableValue
 from .variables import Variables
@@ -31,6 +32,7 @@ class VariableScopes:
         self._global = GlobalVariables(settings)
         self._suite = None
         self._test = None
+        self._suite_locals = []
         self._scopes = [self._global]
         self._variables_set = SetVariables()
 
@@ -59,16 +61,18 @@ class VariableScopes:
     def start_suite(self):
         self._suite = self._global.copy()
         self._scopes.append(self._suite)
+        self._suite_locals.append(NormalizedDict(ignore="_"))
         self._variables_set.start_suite()
         self._variables_set.update(self._suite)
 
     def end_suite(self):
         self._scopes.pop()
+        self._suite_locals.pop()
         self._suite = self._scopes[-1] if len(self._scopes) > 1 else None
         self._variables_set.end_suite()
 
     def start_test(self):
-        self._test = self._suite.copy()
+        self._test = self._suite.copy(update=self._suite_locals[-1])
         self._scopes.append(self._test)
         self._variables_set.start_test()
 
@@ -78,7 +82,8 @@ class VariableScopes:
         self._variables_set.end_test()
 
     def start_keyword(self):
-        kw = self._suite.copy()
+        update = self._suite_locals[-1] if self._test else None
+        kw = self._suite.copy(update)
         self._variables_set.start_keyword()
         self._variables_set.update(kw)
         self._scopes.append(kw)
@@ -113,9 +118,9 @@ class VariableScopes:
             else:
                 scope.set_from_file(variables, overwrite=overwrite)
 
-    def set_from_variable_table(self, variables, overwrite=False):
+    def set_from_variable_section(self, variables, overwrite=False):
         for scope in self._scopes_until_suite:
-            scope.set_from_variable_table(variables, overwrite)
+            scope.set_from_variable_section(variables, overwrite)
 
     def resolve_delayed(self):
         for scope in self._scopes_until_suite:
@@ -129,8 +134,8 @@ class VariableScopes:
     def _set_global_suite_or_test(self, scope, name, value):
         scope[name] = value
         # Avoid creating new list/dict objects in different scopes.
-        if name[0] != '$':
-            name = '$' + name[1:]
+        if name[0] != "$":
+            name = "$" + name[1:]
             value = scope[name]
         return name, value
 
@@ -140,21 +145,29 @@ class VariableScopes:
             return
         for scope in self._scopes_until_suite:
             name, value = self._set_global_suite_or_test(scope, name, value)
-        if children:
-            self._variables_set.set_suite(name, value)
+        self._variables_set.set_suite(name, value, children)
+        # Override possible "suite local variables" (i.e. test variables set on
+        # suite level) if real suite level variable is set.
+        if name in self._suite_locals[-1]:
+            self._suite_locals[-1].pop(name)
 
     def set_test(self, name, value):
-        if self._test is None:
-            raise VariableError('Cannot set test variable when no test is started.')
-        for scope in self._scopes_until_test:
-            name, value = self._set_global_suite_or_test(scope, name, value)
-        self._variables_set.set_test(name, value)
+        if self._test:
+            for scope in self._scopes_until_test:
+                name, value = self._set_global_suite_or_test(scope, name, value)
+            self._variables_set.set_test(name, value)
+        else:
+            # Set test scope variable on suite level. Keep track on added and
+            # overridden variables to allow updating variables when test starts.
+            prev = self._suite.get(name)
+            self.set_suite(name, value)
+            self._suite_locals[-1][name] = prev
 
     def set_keyword(self, name, value):
         self.current[name] = value
         self._variables_set.set_keyword(name, value)
 
-    def set_local_variable(self, name, value):
+    def set_local(self, name, value):
         self.current[name] = value
 
     def as_dict(self, decoration=True):
@@ -162,7 +175,7 @@ class VariableScopes:
 
 
 class GlobalVariables(Variables):
-    _import_by_path_ends = ('.py', '/', os.sep, '.yaml', '.yml')
+    _import_by_path_ends = (".py", "/", os.sep, ".yaml", ".yml", ".json")
 
     def __init__(self, settings):
         super().__init__()
@@ -173,45 +186,70 @@ class GlobalVariables(Variables):
         for name, args in settings.variable_files:
             try:
                 if name.lower().endswith(self._import_by_path_ends):
-                    name = find_file(name, file_type='Variable file')
+                    name = find_file(name, file_type="Variable file")
                 self.set_from_file(name, args)
-            except:
+            except Exception:
                 msg, details = get_error_details()
                 LOGGER.error(msg)
                 LOGGER.info(details)
         for varstr in settings.variables:
-            try:
-                name, value = varstr.split(':', 1)
-            except ValueError:
-                name, value = varstr, ''
-            self['${%s}' % name] = value
+            match = re.fullmatch("([^:]+): ([^:]+):(.*)", varstr)
+            if match:
+                name, typ, value = match.groups()
+                value = self._convert_cli_variable(name, typ, value)
+            elif ":" in varstr:
+                name, value = varstr.split(":", 1)
+            else:
+                name, value = varstr, ""
+            self[f"${{{name}}}"] = value
+
+    def _convert_cli_variable(self, name, typ, value):
+        from robot.api.types import Secret
+        from robot.running import TypeInfo
+
+        var = f"${{{name}: {typ}}}"
+        try:
+            info = TypeInfo.from_variable(var)
+        except DataError as err:
+            raise DataError(f"Invalid command line variable '{var}': {err}")
+        if info.type is Secret:
+            return Secret(value)
+        try:
+            return info.convert(value, var, kind="Command line variable")
+        except ValueError as err:
+            raise DataError(str(err))
 
     def _set_built_in_variables(self, settings):
-        for name, value in [('${TEMPDIR}', abspath(tempfile.gettempdir())),
-                            ('${EXECDIR}', abspath('.')),
-                            ('${OPTIONS}', DotDict({
-                                'include': Tags(settings.include),
-                                'exclude': Tags(settings.exclude),
-                                'skip': Tags(settings.skip),
-                                'skip_on_failure': Tags(settings.skip_on_failure)
-                            })),
-                            ('${/}', os.sep),
-                            ('${:}', os.pathsep),
-                            ('${\\n}', os.linesep),
-                            ('${SPACE}', ' '),
-                            ('${True}', True),
-                            ('${False}', False),
-                            ('${None}', None),
-                            ('${null}', None),
-                            ('${OUTPUT_DIR}', settings.output_directory),
-                            ('${OUTPUT_FILE}', settings.output or 'NONE'),
-                            ('${REPORT_FILE}', settings.report or 'NONE'),
-                            ('${LOG_FILE}', settings.log or 'NONE'),
-                            ('${DEBUG_FILE}', settings.debug_file or 'NONE'),
-                            ('${LOG_LEVEL}', settings.log_level),
-                            ('${PREV_TEST_NAME}', ''),
-                            ('${PREV_TEST_STATUS}', ''),
-                            ('${PREV_TEST_MESSAGE}', '')]:
+        options = DotDict(
+            rpa=settings.rpa,
+            include=Tags(settings.include),
+            exclude=Tags(settings.exclude),
+            skip=Tags(settings.skip),
+            skip_on_failure=Tags(settings.skip_on_failure),
+            console_width=settings.console_width,
+        )
+        for name, value in [
+            ("${TEMPDIR}", abspath(tempfile.gettempdir())),
+            ("${EXECDIR}", abspath(".")),
+            ("${OPTIONS}", options),
+            ("${/}", os.sep),
+            ("${:}", os.pathsep),
+            ("${\\n}", os.linesep),
+            ("${SPACE}", " "),
+            ("${True}", True),
+            ("${False}", False),
+            ("${None}", None),
+            ("${null}", None),
+            ("${OUTPUT_DIR}", str(settings.output_directory)),
+            ("${OUTPUT_FILE}", str(settings.output or "NONE")),
+            ("${REPORT_FILE}", str(settings.report or "NONE")),
+            ("${LOG_FILE}", str(settings.log or "NONE")),
+            ("${DEBUG_FILE}", str(settings.debug_file or "NONE")),
+            ("${LOG_LEVEL}", settings.log_level),
+            ("${PREV_TEST_NAME}", ""),
+            ("${PREV_TEST_STATUS}", ""),
+            ("${PREV_TEST_MESSAGE}", ""),
+        ]:
             self[name] = GlobalVariableValue(value)
 
 
@@ -224,7 +262,7 @@ class SetVariables:
 
     def start_suite(self):
         if not self._scopes:
-            self._suite = NormalizedDict(ignore='_')
+            self._suite = NormalizedDict(ignore="_")
         else:
             self._suite = self._scopes[-1].copy()
         self._scopes.append(self._suite)
@@ -252,8 +290,14 @@ class SetVariables:
             if name in scope:
                 scope.pop(name)
 
-    def set_suite(self, name, value):
-        self._suite[name] = value
+    def set_suite(self, name, value, children=False):
+        for scope in reversed(self._scopes):
+            if children:
+                scope[name] = value
+            elif name in scope:
+                scope.pop(name)
+            if scope is self._suite:
+                break
 
     def set_test(self, name, value):
         for scope in reversed(self._scopes):
