@@ -10,18 +10,18 @@ def passing(*args):
     pass
 
 
-def sleeping(s):
-    seconds = s
+def sleeping(seconds=1):
+    orig = seconds
     while seconds > 0:
         time.sleep(min(seconds, 0.1))
         seconds -= 0.1
-    os.environ['ROBOT_THREAD_TESTING'] = str(s)
-    return s
+    os.environ["ROBOT_THREAD_TESTING"] = str(orig)
+    return orig
 
 
 def returning(arg):
     return arg
 
 
-def failing(msg='xxx'):
+def failing(msg="xxx"):
     raise MyException(msg)
