@@ -1,6 +1,6 @@
-import io
 import sys
 import unittest
+from io import StringIO, TextIOWrapper
 
 from robot.utils import isatty
 from robot.utils.asserts import assert_equal, assert_false, assert_raises
@@ -13,23 +13,23 @@ class TestIsATty(unittest.TestCase):
         assert_equal(isatty(sys.__stderr__), sys.__stderr__.isatty())
 
     def test_with_io(self):
-        with io.StringIO() as stream:
+        with StringIO() as stream:
             assert_false(isatty(stream))
-            wrapper = io.TextIOWrapper(stream, 'UTF-8')
+            wrapper = TextIOWrapper(stream, "UTF-8")
             assert_false(isatty(wrapper))
 
     def test_with_detached_io_buffer(self):
-        with io.StringIO() as stream:
-            wrapper = io.TextIOWrapper(stream, 'UTF-8')
+        with StringIO() as stream:
+            wrapper = TextIOWrapper(stream, "UTF-8")
             wrapper.detach()
             assert_raises((ValueError, AttributeError), wrapper.isatty)
             assert_false(isatty(wrapper))
 
     def test_open_and_closed_file(self):
-        with open(__file__) as file:
+        with open(__file__, encoding="ASCII") as file:
             assert_false(isatty(file))
         assert_false(isatty(file))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
